@@ -17,7 +17,6 @@ using boost::asio::as_tuple;
 using boost::asio::awaitable;
 using boost::asio::dynamic_buffer;
 using boost::asio::co_spawn;
-using boost::asio::deferred;
 using boost::asio::detached;
 using boost::asio::experimental::channel;
 using boost::asio::io_context;
@@ -86,7 +85,7 @@ private:
       {
         // Read an entire line from the client.
         std::size_t length = co_await async_read_until(socket_,
-            dynamic_buffer(data, max_line_length), '\n', deferred);
+            dynamic_buffer(data, max_line_length), '\n');
 
         // Claim the write lock by sending a message to the channel. Since the
         // channel signature is void(), there are no arguments to send in the
@@ -95,12 +94,12 @@ private:
         // non-blocking send.
         if (!write_lock_.try_send())
         {
-          co_await write_lock_.async_send(deferred);
+          co_await write_lock_.async_send();
         }
 
         // Respond to the client with a message, echoing the line they sent.
-        co_await async_write(socket_, "<line>"_buf, deferred);
-        co_await async_write(socket_, dynamic_buffer(data, length), deferred);
+        co_await async_write(socket_, "<line>"_buf);
+        co_await async_write(socket_, dynamic_buffer(data, length));
 
         // Release the lock by receiving the message back again.
         write_lock_.try_receive([](auto...){});
@@ -111,7 +110,7 @@ private:
       stop();
     }
   }
- 
+
   awaitable<void> send_heartbeats()
   {
     steady_timer timer{socket_.get_executor()};
@@ -121,7 +120,7 @@ private:
       {
         // Wait one second before trying to send the next heartbeat.
         timer.expires_after(1s);
-        co_await timer.async_wait(deferred);
+        co_await timer.async_wait();
 
         // Claim the write lock by sending a message to the channel. Since the
         // channel signature is void(), there are no arguments to send in the
@@ -130,7 +129,7 @@ private:
         // non-blocking send.
         if (!write_lock_.try_send())
         {
-          co_await write_lock_.async_send(deferred);
+          co_await write_lock_.async_send();
         }
 
         // Send a heartbeat to the client. As the content of the heartbeat
@@ -138,7 +137,7 @@ private:
         // bytes of the message. The memory associated with a buffer literal is
         // valid for the lifetime of the program, which mean that the buffer
         // can be safely passed as-is to the asynchronous operation.
-        co_await async_write(socket_, "<heartbeat>\n"_buf, deferred);
+        co_await async_write(socket_, "<heartbeat>\n"_buf);
 
         // Release the lock by receiving the message back again.
         write_lock_.try_receive([](auto...){});
@@ -156,7 +155,7 @@ awaitable<void> listen(tcp::acceptor& acceptor)
 {
   for (;;)
   {
-    auto [e, socket] = co_await acceptor.async_accept(as_tuple(deferred));
+    auto [e, socket] = co_await acceptor.async_accept(as_tuple);
     if (!e)
     {
       std::make_shared<line_based_echo_session>(std::move(socket))->start();
