@@ -8,8 +8,6 @@
 // Official repository: https://github.com/boostorg/url
 //
 
-#ifndef BOOST_URL_DETAIL_IMPL_NORMALIZE_IPP
-#define BOOST_URL_DETAIL_IMPL_NORMALIZE_IPP
 
 #include <boost/url/detail/config.hpp>
 #include <boost/url/decode_view.hpp>
@@ -192,100 +190,71 @@ ci_digest(
     }
 }
 
-std::size_t
-path_starts_with(
-    core::string_view lhs,
-    core::string_view rhs) noexcept
-{
-    auto consume_one = [](
-        core::string_view::iterator& it,
-        char &c)
-    {
-        if(*it != '%')
-        {
-            c = *it;
-            ++it;
-            return;
-        }
-        detail::decode_unsafe(
-            &c,
-            &c + 1,
-            core::string_view(it, 3));
-        if (c != '/')
-        {
-            it += 3;
-            return;
-        }
-        c = *it;
-        ++it;
-    };
+/* Check if a string ends with the specified suffix (decoded comparison)
 
-    auto it0 = lhs.begin();
-    auto it1 = rhs.begin();
-    auto end0 = lhs.end();
-    auto end1 = rhs.end();
-    char c0 = 0;
-    char c1 = 0;
-    while (
-        it0 < end0 &&
-        it1 < end1)
-    {
-        consume_one(it0, c0);
-        consume_one(it1, c1);
-        if (c0 != c1)
-            return 0;
-    }
-    if (it1 == end1)
-        return it0 - lhs.begin();
-    return 0;
-}
+   This function determines if a string ends with the specified suffix
+   when the string and suffix are compared after percent-decoding.
 
+   @param str The string to check (percent-encoded)
+   @param suffix The suffix to check for (percent-decoded)
+   @return The number of encoded chars consumed in the string
+ */
 std::size_t
 path_ends_with(
-    core::string_view lhs,
-    core::string_view rhs) noexcept
+    core::string_view str,
+    core::string_view suffix) noexcept
 {
+    BOOST_ASSERT(!str.empty());
+    BOOST_ASSERT(!suffix.empty());
+    BOOST_ASSERT(!suffix.contains("%2F"));
+    BOOST_ASSERT(!suffix.contains("%2f"));
     auto consume_last = [](
         core::string_view::iterator& it,
         core::string_view::iterator& end,
         char& c)
     {
+        BOOST_ASSERT(end > it);
+        BOOST_ASSERT(it != end);
         if ((end - it) < 3 ||
             *(std::prev(end, 3)) != '%')
         {
             c = *--end;
-            return;
+            return false;
         }
         detail::decode_unsafe(
             &c,
             &c + 1,
             core::string_view(std::prev(
                 end, 3), 3));
-        if (c != '/')
-        {
-            end -= 3;
-            return;
-        }
-        c = *--end;
+        end -= 3;
+        return true;
     };
 
-    auto it0 = lhs.begin();
-    auto it1 = rhs.begin();
-    auto end0 = lhs.end();
-    auto end1 = rhs.end();
+    auto it0 = str.begin();
+    auto end0 = str.end();
+    auto it1 = suffix.begin();
+    auto end1 = suffix.end();
     char c0 = 0;
     char c1 = 0;
     while(
         it0 < end0 &&
         it1 < end1)
     {
-        consume_last(it0, end0, c0);
+        bool const is_encoded = consume_last(it0, end0, c0);
+        // The suffix never contains an encoded slash (%2F), and a decoded
+        // slash is not equivalent to an encoded slash
+        if (is_encoded && c0 == '/')
+            return 0;
         consume_last(it1, end1, c1);
         if (c0 != c1)
             return 0;
     }
-    if (it1 == end1)
-        return lhs.end() - end0;
+    bool const consumed_suffix = it1 == end1;
+    if (consumed_suffix)
+    {
+        std::size_t const consumed_encoded = str.end() - end0;
+        return consumed_encoded;
+    }
     return 0;
 }
 
@@ -353,21 +322,33 @@ remove_dot_segments(
             {
                 str.remove_prefix(1);
                 ++n;
+                continue;
             }
-            else if (str.size() > 2 &&
-                     str[0] == '%' &&
-                     str[1] == '2' &&
-                     (str[2] == 'e' ||
-                      str[2] == 'E'))
-            {
-                str.remove_prefix(3);
-                n += 3;
-            }
-            else
-            {
-                n = 0;
-                return false;
-            }
+
+            // In the general case, we would need to
+            // check if the next char is an encoded
+            // dot.
+            // However, an encoded dot in `str`
+            // would have already been decoded in
+            // url_base::normalize_path().
+            // This needs to be undone if
+            // `remove_dot_segments` is used in a
+            // different context.
+            // if (str.size() > 2 &&
+            //     c == '.'
+            //     &&
+            //     str[0] == '%' &&
+            //     str[1] == '2' &&
+            //     (str[2] == 'e' ||
+            //      str[2] == 'E'))
+            // {
+            //     str.remove_prefix(3);
+            //     n += 3;
+            //     continue;
+            // }
+
+            n = 0;
+            return false;
         }
         return true;
     };
@@ -486,6 +467,12 @@ remove_dot_segments(
                 }
                 else
                 {
+                    // AFREITAS: Although we have no formal proof
+                    // for that, the output can't be relative
+                    // and empty at this point because relative
+                    // paths will fall in the `dest0 != dest`
+                    // case above of this rule C and then the
+                    // general case of rule E for "..".
                     append(dest, end, "..");
                 }
             }
@@ -537,6 +524,12 @@ remove_dot_segments(
                 }
                 else
                 {
+                    // AFREITAS: Although we have no formal proof
+                    // for that, the output can't be relative
+                    // and empty at this point because relative
+                    // paths will fall in the `dest0 != dest`
+                    // case above of this rule C and then the
+                    // general case of rule E for "..".
                     append(dest, end, "..");
                 }
             }
@@ -589,32 +582,32 @@ path_pop_back( core::string_view& s )
 
 void
 pop_last_segment(
-    core::string_view& s,
-    core::string_view& c,
+    core::string_view& str,
+    core::string_view& seg,
     std::size_t& level,
-    bool r) noexcept
+    bool remove_unmatched) noexcept
 {
-    c = {};
+    seg = {};
     std::size_t n = 0;
-    while (!s.empty())
+    while (!str.empty())
     {
         // B.  if the input buffer begins with a
         // prefix of "/./" or "/.", where "." is
         // a complete path segment, then replace
         // that prefix with "/" in the input
         // buffer; otherwise,
-        n = detail::path_ends_with(s, "/./");
+        n = detail::path_ends_with(str, "/./");
         if (n)
         {
-            c = s.substr(s.size() - n);
-            s.remove_suffix(n);
+            seg = str.substr(str.size() - n);
+            str.remove_suffix(n);
             continue;
         }
-        n = detail::path_ends_with(s, "/.");
+        n = detail::path_ends_with(str, "/.");
         if (n)
         {
-            c = s.substr(s.size() - n, 1);
-            s.remove_suffix(n);
+            seg = str.substr(str.size() - n, 1);
+            str.remove_suffix(n);
             continue;
         }
 
@@ -626,19 +619,19 @@ pop_last_segment(
         // segment and its preceding "/"
         // (if any) from the output buffer
         // otherwise,
-        n = detail::path_ends_with(s, "/../");
+        n = detail::path_ends_with(str, "/../");
         if (n)
         {
-            c = s.substr(s.size() - n);
-            s.remove_suffix(n);
+            seg = str.substr(str.size() - n);
+            str.remove_suffix(n);
             ++level;
             continue;
         }
-        n = detail::path_ends_with(s, "/..");
+        n = detail::path_ends_with(str, "/..");
         if (n)
         {
-            c = s.substr(s.size() - n);
-            s.remove_suffix(n);
+            seg = str.substr(str.size() - n);
+            str.remove_suffix(n);
             ++level;
             continue;
         }
@@ -650,64 +643,71 @@ pop_last_segment(
         // characters up to, but not including,
         // the next "/" character or the end of
         // the input buffer.
-        std::size_t p = s.size() > 1
-            ? s.find_last_of('/', s.size() - 2)
+        std::size_t p = str.size() > 1
+            ? str.find_last_of('/', str.size() - 2)
             : core::string_view::npos;
         if (p != core::string_view::npos)
         {
-            c = s.substr(p + 1);
-            s.remove_suffix(c.size());
+            seg = str.substr(p + 1);
+            str.remove_suffix(seg.size());
         }
         else
         {
-            c = s;
-            s = {};
+            seg = str;
+            str = {};
         }
 
         if (level == 0)
             return;
-        if (!s.empty())
+        if (!str.empty())
             --level;
     }
     // we still need to skip n_skip + 1
     // but the string is empty
-    if (r && level)
+    if (remove_unmatched && level)
     {
-        c = "/";
+        seg = "/";
         level = 0;
         return;
     }
     else if (level)
     {
-        if (c.empty())
-            c = "/..";
+        if (!seg.empty())
+        {
+            seg = "/../";
+        }
         else
-            c = "/../";
+        {
+            // AFREITAS: this condition
+            // is correct, but it might
+            // unreachable.
+            seg = "/..";
+        }
         --level;
         return;
     }
-    c = {};
+    seg = {};
 }
 
 void
 normalized_path_digest(
-    core::string_view s,
+    core::string_view str,
     bool remove_unmatched,
     fnv_1a& hasher) noexcept
 {
-    core::string_view child;
+    core::string_view seg;
     std::size_t level = 0;
     do
     {
         pop_last_segment(
-            s, child, level, remove_unmatched);
-        while (!child.empty())
+            str, seg, level, remove_unmatched);
+        while (!seg.empty())
         {
-            char c = path_pop_back(child);
+            char c = path_pop_back(seg);
             hasher.put(c);
         }
     }
-    while (!s.empty());
+    while (!str.empty());
 }
 
 // compare segments as if there were a normalized
@@ -906,4 +906,4 @@ segments_compare(
 } // urls
 } // boost
 
-#endif
+
